/**
 * @file libLog.ts
 * @notice 로그 라이브러리 정의
 * @author jhhong
 */
import winston from "winston";
import 'winston-daily-rotate-file';
/**
 * Winston Log level
 */
export declare type LoggerType = LibLogger | null;
declare class LibLogger {
    callsite: any;
    logger: winston.Logger;
    color: boolean;
    /**
     * @notice LibLogger 생성자 함수이다.
     * @param id 로깅 식별자
     * @author jhhong
     */
    constructor(id: string);
}
/**
 * @notice 로그모듈을 초기화한다.
 * @param id 로깅 모듈 식별자
 * @param conf 로깅 환경구성파일(.env) 위치
 * @dev 비동기처리 필요없음
 * @author jhhong
 */
export declare const initLog: (id: string, conf: string) => Promise<void>;
/**
 * @notice 로그를 출력한다.
 * @dev initLog 선행 필수
 * @param prefix 로그레벨 지정자 (error, warn, info, debug, verbose, silly)
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
export declare const Log: (prefix: string, str: string) => void;
/**
 * @notice RED COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
export declare const consoleRed: (str: string) => string;
/**
 * @notice GREEN COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
export declare const consoleGreen: (str: string) => string;
/**
 * @notice BLUE COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
export declare const consoleBlue: (str: string) => string;
/**
 * @notice CYAN COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
export declare const consoleCyan: (str: string) => string;
/**
 * @notice GRAY COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
export declare const consoleGray: (str: string) => string;
export {};
