"use strict";
/**
 * @file libLog.ts
 * @notice 로그 라이브러리 정의
 * @author jhhong
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.consoleGray = exports.consoleCyan = exports.consoleBlue = exports.consoleGreen = exports.consoleRed = exports.Log = exports.initLog = void 0;
const callsite_1 = __importDefault(require("callsite"));
const colors_1 = __importDefault(require("colors"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const winston_1 = __importDefault(require("winston"));
require("winston-daily-rotate-file");
const source_map_support_1 = require("source-map-support");
const env = __importStar(require("dotenv"));
/// GLOBAL
let inst;
/// LibLogger CLASS 정의
class LibLogger {
    /**
     * @notice LibLogger 생성자 함수이다.
     * @param id 로깅 식별자
     * @author jhhong
     */
    constructor(id) {
        this.color = false; /// 콘솔 칼러 활성화 여부: 파일 로깅 활성화 시 콘솔 칼러 비활성화
        const propConsole = {
            level: `${process.env.LOG_LEVEL}`.toLowerCase(),
            format: winston_1.default.format.combine(// 로그포맷 정의: 아래 포맷들이 결합되어 출력
            winston_1.default.format.timestamp({ format: `${process.env.LOG_TIMESTAMP_FMT}` }), // 로그포맷: timestamp 형식 정의
            winston_1.default.format.colorize(), // 로그포맷: 글자 칼러 enable
            winston_1.default.format.printf((data) => `${data.timestamp} ${data.level}: ${data.message}`) // 출력포맷--> timestamp level: 내용
            )
        };
        let consoleSetting = new winston_1.default.transports.Console(propConsole);
        this.logger = winston_1.default.createLogger({ transports: [consoleSetting] });
        this.callsite = callsite_1.default;
        if (`${process.env.LOGFILE_ENABLE}` == 'true') {
            const logDir = path_1.default.resolve(`${process.env.LOGFILE_DIR}`, `${id}`); // 로그 저장 경로
            if (!fs_1.default.existsSync(logDir)) {
                fs_1.default.mkdirSync(logDir, { recursive: true });
            }
            /// maxSize, maxFiles 에 입력될 String 체크
            const propFiles = {
                level: `${process.env.LOG_LEVEL}`.toLowerCase(),
                filename: `${logDir}/%DATE%.log`,
                datePattern: `${process.env.LOGFILE_DATE_PATTERN}`,
                zippedArchive: (`${process.env.LOGFILE_ENABLE}` == `true`) ? (true) : (false),
                maxSize: `${process.env.LOGFILE_MAXSIZE}`,
                maxFiles: `${process.env.LOGFILE_MAXNUM}`,
                format: winston_1.default.format.combine(// 로그포맷 정의: 아래 포맷들이 결합되어 출력
                winston_1.default.format.timestamp({ format: `${process.env.LOG_TIMESTAMP_FMT}` }), // 로그포맷: timestamp 형식 정의
                winston_1.default.format.simple(), winston_1.default.format.printf((data) => `${data.timestamp} ${data.level}: ${data.message}`) // 출력포맷--> timestamp level: 내용
                )
            };
            let fileSetting = new winston_1.default.transports.DailyRotateFile(propFiles);
            this.logger.add(fileSetting);
            this.color = false;
        }
        else {
            this.color = true;
        }
    }
}
/**
 * @notice 로그모듈을 초기화한다.
 * @param id 로깅 모듈 식별자
 * @param conf 로깅 환경구성파일(.env) 위치
 * @dev 비동기처리 필요없음
 * @author jhhong
 */
const initLog = function (id, conf) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            env.config({ path: conf });
            if (`${process.env.LOG_ENABLE}` == 'true') {
                if (inst != null) {
                    throw new Error(`Log instance is aleady initialized!`);
                }
                inst = new LibLogger(id);
            }
        }
        catch (error) {
            console.log(error);
        }
    });
};
exports.initLog = initLog;
/**
 * @notice 로그를 출력한다.
 * @dev initLog 선행 필수
 * @param prefix 로그레벨 지정자 (error, warn, info, debug, verbose, silly)
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
const Log = function (prefix, str) {
    if (inst != null) {
        let callPos = (0, source_map_support_1.wrapCallSite)(inst.callsite()[1]);
        let filePath = callPos.getFileName();
        if (typeof (filePath) == "string") {
            const fullPath = filePath.split('/');
            const fileName = fullPath[fullPath.length - 1];
            const lineNumber = callPos.getLineNumber();
            inst.logger.log({ level: prefix.toLowerCase(), message: `<${fileName}:${lineNumber}> ${str}` });
        }
    }
};
exports.Log = Log;
/**
 * @notice RED COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
const consoleRed = function (str) {
    return (inst != null && inst.color == true) ? (colors_1.default.red(str)) : (str);
};
exports.consoleRed = consoleRed;
/**
 * @notice GREEN COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
const consoleGreen = function (str) {
    return (inst != null && inst.color == true) ? (colors_1.default.green(str)) : (str);
};
exports.consoleGreen = consoleGreen;
/**
 * @notice BLUE COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
const consoleBlue = function (str) {
    return (inst != null && inst.color == true) ? (colors_1.default.blue(str)) : (str);
};
exports.consoleBlue = consoleBlue;
/**
 * @notice CYAN COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
const consoleCyan = function (str) {
    return (inst != null && inst.color == true) ? (colors_1.default.cyan(str)) : (str);
};
exports.consoleCyan = consoleCyan;
/**
 * @notice GRAY COLOR 출력을 위한 태그가 추가된다.
 * @dev enableLogFile이 호출되면 비활성화됨
 * @param str 출력할 데이터 (문자열)
 * @author jhhong
 */
const consoleGray = function (str) {
    return (inst != null && inst.color == true) ? (colors_1.default.gray(str)) : (str);
};
exports.consoleGray = consoleGray;
//# sourceMappingURL=index.js.map